
{% load i18n site_config %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">

    <style>

        .heading {
            border-bottom: 2px solid;
            margin: 5px 0;
            text-align: center;
        }

        table {
            width: 100%;
            border: 1px solid #0a0a0a;
            border-spacing: 0;
        }

        table td,
        table th {
            border: 1px solid #0a0a0a;
            font-size: 13px;
        }

        table th {
            background-color: #c0c0c0;
        }

        table td {
            padding-left: 3px;
        }

        .cell-number {
            width: 10%;
            text-align: center;
        }

        .cell-total {
            font-weight: bold;
            text-align: right;
            border: none;
        }

        .text-right {
            text-align: right;
        }

    </style>
</head>
<body style="padding: 0; margin: 0;">

    {% get_site_config as config %}

    <h3 class="heading">
        {% trans 'Act of work performed' %} {% trans '#' %}{{ sale.id }} <br />
        <span style="font-size: 13px">
            {% trans 'from' %}
            {{ sale.created|date:'d.m.Y' }}
        </span>
    </h3>

    {{ config.sale_print_text|default:'' }}

    {% with sale.customer as customer %}
        {% if customer.name %}
            {{ customer.name }} <br />
        {% endif %}
        {% if customer.phone %}
            {{ customer.phone }} <br />
        {% endif %}
        {% if customer.vin %}
            {{ customer.vin }} <br />
        {% endif %}
    {% endwith %}

    {% include 'services/print-services-table.html' %}

    <script>
        window.print();
    </script>
</body>
</html>
