# Generated by Django 3.0.13 on 2021-07-19 13:21

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("services", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServiceWorker",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        max_length=255, verbose_name="Worker name"
                    ),
                ),
            ],
            options={
                "verbose_name": "Service worker",
                "verbose_name_plural": "Service workers",
            },
        ),
        migrations.AlterModelTable(
            name="service",
            table="services_service",
        ),
        migrations.AddField(
            model_name="service",
            name="worker",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="services",
                to="services.ServiceWorker",
                verbose_name="Worker",
            ),
        ),
    ]
