
{% load widget_tweaks %}

<tr data-role="list-item" data-item-id="{{ object.id }}">
    <td>{{ object.code }}</td>
    <td>
        {{ object.name }}
    </td>
    <td>
        {{ form.worker }}
    </td>
    <td class="invoice-editable-cell">
        <input data-role="qty-input"
               type="text"
               name="qty"
               data-url="{{ object.api_url }}"
               value="{{ object.qty }}">
    </td>
    <td class="invoice-editable-cell">
        <input data-role="price-input"
               type="text"
               name="price"
               data-url="{{ object.api_url }}"
               value="{{ object.price }}">
    </td>
    <td>
        <button type="button"
                data-role="delete-action"
                data-item-id="{{ object.id }}"
                data-url="{{ object.api_url }}"
                class="btn btn-xs btn-danger pull-right">
            <i class="fa fa-trash"></i>
        </button>
    </td>
</tr>
